Package: CytoDx
Type: Package
Title: Robust prediction of clinical outcomes using cytometry data
        without cell gating
Version: 1.33.0
Author: Zicheng Hu
Maintainer: Zicheng Hu <zicheng.hu@ucsf.edu>
Description: This package provides functions that predict clinical outcomes using single cell data (such as flow cytometry data, RNA single cell sequencing data) without the requirement of cell gating or clustering. 
License: GPL-2
Encoding: UTF-8
Imports: doParallel, dplyr, glmnet, rpart, rpart.plot, stats,
        flowCore,grDevices, graphics, utils
Depends: R (>= 3.5)
Suggests: knitr, rmarkdown
VignetteBuilder: knitr, rmarkdown
RoxygenNote: 6.1.0
biocViews: ImmunoOncology, CellBiology, FlowCytometry,
        StatisticalMethod, Software, CellBasedAssays, Regression,
        Classification, Survival
git_url: https://git.bioconductor.org/packages/CytoDx
git_branch: devel
git_last_commit: 0f9a681
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 22:06:36 UTC; biocbuild
