# Generated by roxygen2: do not edit by hand

export(CytoDx.fit)
export(CytoDx.pred)
export(fcs2DF)
export(meanUnique)
export(pRank)
export(rank.ub.average)
export(set2DF)
export(treeGate)
import(grDevices)
import(graphics)
importFrom(doParallel,registerDoParallel)
importFrom(dplyr,"%>%")
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate_all)
importFrom(dplyr,summarise_all)
importFrom(flowCore,arcsinhTransform)
importFrom(flowCore,colnames)
importFrom(flowCore,compensate)
importFrom(flowCore,fsApply)
importFrom(flowCore,keyword)
importFrom(flowCore,logTransform)
importFrom(flowCore,read.flowSet)
importFrom(flowCore,transform)
importFrom(flowCore,transformList)
importFrom(glmnet,cv.glmnet)
importFrom(glmnet,glmnet)
importFrom(rpart,rpart)
importFrom(rpart,rpart.control)
importFrom(rpart.plot,rpart.plot)
importFrom(stats,predict)
importFrom(utils,read.csv)
